#
# spec file for package spdlog
#
# Copyright (c) 2018 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via http://bugs.opensuse.org/
#


Name:           spdlog
Version:        0.16.3
Release:        lp151.3.3.1
Summary:        C++ header only logging library
License:        MIT
Group:          Development/Languages/C and C++
Url:            https://github.com/gabime/spdlog/
Source0:        https://github.com/gabime/spdlog/archive/v%{version}.tar.gz#/%{name}-%{version}.tar.gz
BuildRequires:  cmake
BuildRequires:  dos2unix
BuildRequires:  gcc-c++
BuildRequires:  pkgconfig

%description
spdlog is a C++ logging library implemented in headers only. It
supports the ostream call style, has an (optional) asynchronous mode
with lockfree queues, allows for custom formatting, knows
single-/multi-threaded loggers, has various log targets, log
rotation, can be extended with custom log targets, and has
compile-time and run-time severity-based filtering.

%package        devel
Summary:        Development files for spdlog, a C++ header-only logging library
Group:          Development/Languages/C and C++

%description    devel
spdlog is a C++ logging library implemented in headers only. It
supports the ostream call style, has an (optional) asynchronous mode
with lockfree queues, allows for custom formatting, knows
single-/multi-threaded loggers, has various log targets, log
rotation, can be extended with custom log targets, and has
compile-time and run-time severity-based filtering.

%prep
%setup -q
dos2unix README.md

%build
%cmake
make %{?_smp_mflags}

%install
%cmake_install

%check
%ctest

%files devel
%doc README.md
%license LICENSE
%{_includedir}/%{name}
%{_libdir}/cmake/%{name}
%{_libdir}/pkgconfig/%{name}.pc

%changelog
* Tue Apr 17 2018 jengelh@inai.de
- Remove excess hyping from description.
* Mon Apr 16 2018 adam.majer@suse.de
- run unit tests in the %%check target
- install LICENSE as a %%license, not a %%doc
* Sat Apr 14 2018 aloisio@gmx.com
- Update to version 0.16.3
  * Fix sleep issue (#609) under MSVC that happens when changing
    the clock backwards (pull #610) - Thanks @joaomoreno
  * Ensure that marcos always expand to expressions (pull #604) -
    Thanks @sam-lunt
  * Add global flush_on function (pull #605) - Thanks @sam-lunt
  * Fix conversion warning (#595, pull #596) - Thanks @Broekman
  version 0.16.2
  * Fixed a bug in extracting log files extension (#589) - Thanks
    @fcharlie
  version 0.16.1
  * Fixed the version strings to 0.16.1 in spdlog.h and
    CMakeLists.txt
  * Fixed compiler warning in tests - Thanks @horar
  version 0.16.0
  * Rotating and daily log files keep their extension (e.g
    "mylog.3.txt" and not "mylog.txt.3")
  * Optional support for printf formatting (enabled using #define
    SPDLOG_FMT_PRINTF) - Thanks @fogo
  * Async log: increased sleep to to 500ms the worker in loop
    when the queue is empty
  * Fixed thread safety bug in flush() - added lock on flush in
    base_sink
  * Breaking change: Removed all *_if functions (trace_if,
    debug_if, info_if,..) because they are redundant and
    confusing way to preform simple if
  * Swallow only std::exceptions. report about, and re-throw
    other, unexpected exception types.
  * Support msvc_sink on all windows compiler (windebug-sink) -
    Thanks @jpcima
  * Added facilty param for syslog - Thanks @adubovikov
  * correct include path for sink/syslog_sink.h - Thanks @jpcima
  * Fix include paths - Thanks @daylanKifky
  * Some fixes in the async queue size estimation - Thanks
    @Subenle
  * Fixed cygwin support
  * Adding additional build environments for AppVeyor- Thanks
    @rkollataj
  * Fix warnings which are caused by C style cast - Thanks
    @knowledge4igor
  * Make short month names match in length - Thanks @berkus
  * Fix typos in code and comments - Thanks @berkus
  * Fixed missing i_formatter implementation
  * Fix SPDLOG_WCHAR_TO_UTF8_SUPPORT wchar_t logging - Thanks
    @hestad
  * Added formatter for unix epoch time in seconds (%%E format
    flag) - Thanks @jasonbeach
  * Compiler-dependent line numbering in SPDLOG_TRACE - Thanks
    @elelel
  * Improved cmake and CMakeLists.txt - Thanks @mrpelotazo and
    @Lectem
  version 0.14.0
  * Upgraded the bundled fmt lib to version 4.0.0
  * Fixed crash in async logger in older gcc version 4.8.5
    (268222e).
  * Fixed various sanitizer warnings.
  * Improved Android support (#422, #427).
  * Add an optional final qualifier to types (#425) for potential
    compiler optimisations.
  * Support for Alpine Linux (#435, #436).
  * Add wide string to utf8 string support (#442).
  * Don't use color escape codes if terminal doesn't support them
    bd25f59 .
  * Optional message counter feature (#445).
  * Fix OSX builds of details/os.h (#447).
  * Fix vs 2015 build error (#449).
  * UTC support (#451).
  * MinGw build fix (#456).
  * Add create_async factory functions for async loggers (#459).
  * Conditional logging implementation (#460).
  * More meaningful thread id for OSX (#463).
  * Add set_color to ansicolor_sink (#465).
  * Ability to override log level names in the log messages
    (#473).
  * Added TRACE_IF and DEBUG_IF macro definitions when TRACE_ON
    and DEBUG.
  * Fixed background color bug in windows terminal (#484).
  * Gentoo support (#502).
  * Fixed warning for missing enumeration value in tests (#488,
    [#490]).
  * Fixed numerous typos in code and comments.
  version 0.13.0
  * Bumped the bundled fmt library to version 3.0.1.
  * Fixed issue #333 (unexpected appending of "txt" at the end of
    a log filename).
  * Fixed issue #396 (custom error handler not called in async
    loggers).
  * Fixed issue #403 (ambiguous warnings on some compilers).
  * Use double-braces in std::array initialisation.
  version 0.12.0
  * Added %%P (process Id) to format string
  * Exposed logger sinks via logger->sinks().
  * Windows native console color support.
  * Fixed vc warning on x64 build
  * Better support for for older win32 targets (WinXP/Win2003)
  * Fixed issue #300
  * Fix issue #315
  * Fix issue #317 (Build error on raspberry pi)
  * Better cmake support : list spdlog's content in IDEs
  * Fix compilation error C2664 on VS2013
  * Store thread_id in tls for better performance
  * Use the feature checking macros to detect thread_local
    support in clang.
  * Added option to prevent child processes from inheriting log
    file desciptors
  * Added SPDLOG_VERSION` macro to spdlog.h
  * Replaced static global std::string arrays by Meyer singletons
    for better thread safety
  version 0.11.0
  * sink log levels
  * various bug fixes
  version 0.10.0
  * No exceptions will be thrown while logging (with optional
    error handlers).
  * FreeBSD support.
  * Solaris support.
  * syslog disabled by default for faster compilation.
  * Bug fixes and improvements.
  version 0.9.0
  * cosmetic fix in utc_minutes_offset when throwing
* Mon Feb  1 2016 meissner@suse.com
- a c++ header only logging library
